@@ -5,10 +5,10 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.001_02';
+our $VERSION   = '0.001_03';
 
 use Moo;
-use AtteanX::Store::SPARQL::Plan::BGP;
+use AtteanX::Plan::SPARQLBGP;
 use Carp qw(croak);
 use Attean::RDF;
 use Types::Standard qw(InstanceOf);
