@@ -3,7 +3,7 @@ package LWP::UserAgent::SemWebCache;
 use 5.006000;
 
 our $AUTHORITY = 'cpan:KJETILK';
-our $VERSION   = '0.001_02';
+our $VERSION   = '0.001_03';
 
 use Moo;
 use Digest::MD4 qw(md4_base64);
@@ -22,7 +22,9 @@ has key => (
 sub _build_key { return md4_base64(shift->request_uri->canonical->as_string) }
 
 
-with 'LWP::UserAgent::Role::CHICaching', 'LWP::UserAgent::Role::CHICaching::VaryNotAsterisk';
+with 'LWP::UserAgent::Role::CHICaching',
+     'LWP::UserAgent::Role::CHICaching::VaryNotAsterisk',
+     'LWP::UserAgent::Role::CHICaching::SimpleMungeResponse';
 
 1;
 
